""" unit tests for uule grabber """
import unittest
import uule_grabber


class TestUuleGrabber(unittest.TestCase):
    """ uule_grabber tests """

    def test_uule_secret(self):
        """ Checks UULE secret code algorithm  """
        control_list = [(4, "E"), (25, "Z"), (26, "a"),
                        (43, "r"), (51, "z"), (52, "0"),
                        (61, "9"), (62, "-"), (63, "_"),
                        (64, "A"), (76, "M"), (83, "T")]
        for value, expected in control_list:
            self.assertEqual(uule_grabber.uule_secret(value),
                             expected, "Control value: {}".format(value))

    def test_uule(self):
        """ Checks UULE code algorithm """
        control_list = [("Lezigne,Pays de la Loire,France", "w+CAIQICIfTGV6aWduZSxQYXlzIGRlIGxhIExvaXJlLEZyYW5jZQ"),
                        ("Reze,Pays de la Loire,France",
                         "w+CAIQICIcUmV6ZSxQYXlzIGRlIGxhIExvaXJlLEZyYW5jZQ"),
                        ("Chicago,Illinois,United States",
                         "w+CAIQICIeQ2hpY2FnbyxJbGxpbm9pcyxVbml0ZWQgU3RhdGVz"),
                        ("Washington,District of Columbia,United States",
                         "w+CAIQICItV2FzaGluZ3RvbixEaXN0cmljdCBvZiBDb2x1bWJpYSxVbml0ZWQgU3RhdGVz"),
                        ("Jacksonville Beach,Florida,United States", "w+CAIQICIoSmFja3NvbnZpbGxlIEJlYWNoLEZsb3JpZGEsVW5pdGVkIFN0YXRlcw")]
        for value, expected in control_list:
            self.assertEqual(uule_grabber.uule(value),
                             expected, "Control value: {}".format(value))


if __name__ == '__main__':
    unittest.main()



from setuptools import setup
setup(
    name="uule_grabber",
    packages=["uule_grabber"],
    version="0.1",
    description="Generates UULE codes for Google Search ",
    author="Kemal Ogun Isik",
    author_email="ogunisik@gmail.com",
    url="https://github.com/ogun/uule_grabber",
    download_url="https://github.com/ogun/uule_grabber/archive/0.1.tar.gz",
    classifiers=[],
)



""" Generates UULE codes for Google Search """
import string
import base64

def uule_secret(length: int) -> str:
    """ Creates UULE secret """
    secret_list = list(string.ascii_uppercase) + \
        list(string.ascii_lowercase) + list(string.digits) + ["-", "_"]
    return secret_list[length % len(secret_list)]


def uule(city: str) -> str:
    """ Creates UULE code """
    secret = uule_secret(len(city))
    hashed = base64.standard_b64encode(city.encode()).decode().strip("=")
    return "w+CAIQICI{}{}".format(secret, hashed)
